import { NgModule } from "@angular/core";
import { PreloadAllModules, RouterModule, Routes } from "@angular/router";
import { AuthGuard } from "./guards/auth.guard";

const routes: Routes = [
	{
		path: "",
		loadChildren: () => import("./pages/tabs/tabs.module").then((m) => m.TabsPageModule),
	},
	{
		path: "shop",
		loadChildren: () => import("./pages/shop/shop.module").then((m) => m.ShopPageModule),
		canActivate: [AuthGuard],
	},
	{
		path: "sign-up",
		loadChildren: () => import("./pages/sign-up/sign-up.module").then((m) => m.SignUpPageModule),
	},
	{
		path: "theaters",
		loadChildren: () => import("./pages/theaters/theaters.module").then((m) => m.TheatersPageModule),
	},
	{
		path: "login",
		loadChildren: () => import("./pages/sign-in/sign-in.module").then((m) => m.SignInPageModule),
	},
	{
		path: "movie-detail",
		loadChildren: () => import("./pages/movie-detail/movie-detail.module").then((m) => m.MovieDetailPageModule),
	},
	{
		path: "choose-seat",
		loadChildren: () => import("./pages/choose-seat/choose-seat.module").then((m) => m.ChooseSeatPageModule),
		canActivate: [AuthGuard],
	},
	{
		path: "forgot",
		loadChildren: () => import("./pages/forgot/forgot.module").then((m) => m.ForgotPageModule),
	},
	{
		path: "cart",
		loadChildren: () => import("./pages/cart/cart.module").then((m) => m.CartPageModule),
		canActivate: [AuthGuard],
	},
	{
		path: "card",
		loadChildren: () => import("./pages/card/card.module").then((m) => m.CardPageModule),
		canActivate: [AuthGuard],
	},
	{
		path: "ticket",
		loadChildren: () => import("./pages/ticket/ticket.module").then((m) => m.TicketPageModule),
		canActivate: [AuthGuard],
	},
	{
		path: "ticket-detail",
		loadChildren: () => import("./pages/ticket-detail/ticket-detail.module").then((m) => m.TicketDetailPageModule),
		canActivate: [AuthGuard],
	},
	{
		path: "shop-quantity",
		loadChildren: () => import("./pages/shop-quantity/shop-quantity.module").then((m) => m.ShopQuantityPageModule),
	},

	{
		path: "account",
		loadChildren: () => import("./pages/account/account.module").then((m) => m.AccountPageModule),
	}

];
@NgModule({
	imports: [RouterModule.forRoot(routes, { preloadingStrategy: PreloadAllModules })],
	exports: [RouterModule],
})
export class AppRoutingModule {}
