import { Component, OnInit } from "@angular/core";
import { Router, NavigationEnd } from "@angular/router";
import { Storage } from "@ionic/storage";
import { ShopService } from "../../services/shop.service";
import { AuthService } from "../../services/auth.service";
import { ToastController } from "@ionic/angular";
import { AuthGuard } from "../../guards/auth.guard";

@Component({
	selector: "app-navbar",
	templateUrl: "./navbar.component.html",
	styleUrls: ["./navbar.component.scss"],
})
export class NavbarComponent implements OnInit {
	cartList: any[] = [];
	seatList: any[] = [];
	mySubscription: any;
	realQtyCart: number = 0;
	realQtySeats: number = 0;
	seatsSelected: any;
	user_image: any = 0;

	constructor(
		private router: Router,
		private storage: Storage,
		private shopService: ShopService,
		private authService: AuthService,
		private toastController: ToastController,
		private authguard: AuthGuard
	) {}

	ngOnInit() {
		this.shopService.getCartData().subscribe((data) => {
			this.storage.set("cart", data);
			this.realQtyCart = 0;
			for (let product of data) {
				this.realQtyCart += product.qty;
			}
		});

		this.shopService.getSeatsData().subscribe((data) => {
			this.storage.set("seats_selected", data);
			this.realQtySeats = data.length;
		});

		this.authService.getUserSub().subscribe((data) => {
			if (data && data.picture) this.user_image = data.picture;
			//this.storage.set("user_image", data.picture);
		});

		this.storage.get("auth").then((resp) => {
			if (resp) {
				if (resp.picture) {
					this.user_image = resp.picture;
					//this.storage.set("user_image", resp.picture);
				} else {
					this.user_image = 0;
				}
			}
		});

		this.storage.get("cart").then((val) => {
			if (val) {
				for (let product of val) {
					this.realQtyCart += product.qty;
				}
			}
			this.cartList = val;
		});

		this.storage.get("seats_selected").then((resp) => {
			if (resp && resp.seats && resp.seats.length > 0) {
				this.seatList = resp.seats;
				this.realQtySeats = resp.seats.length;
			}
		});
	}

	login() {
		if (!this.authguard.isLoggin()) {
			this.router.navigate(["/login"]);
		}else{
			//this.presentToast("You are already logged in");
			this.router.navigate(["/account"]);
		}
	}

	goToCart() {
		this.router.navigate(["/cart"]);
	}

	ngOnDestroy() {
		if (this.mySubscription) {
			this.mySubscription.unsubscribe();
		}
	}

	async presentToast(msg) {
		const toast = await this.toastController.create({
			message: msg,
			duration: 2000,
			color: "dark",
		});
		toast.present();
	}
}
