import { AuthService } from "./../services/auth.service";
import { Injectable } from "@angular/core";
import { ActivatedRouteSnapshot, CanActivate, Router } from "@angular/router";
import { Observable } from "rxjs";
import { take, map } from "rxjs/operators";
import { AlertController, ToastController } from "@ionic/angular";
import { BehaviorSubject } from "rxjs/internal/BehaviorSubject";

@Injectable({
	providedIn: "root",
})
export class AuthGuard implements CanActivate {
	constructor(private router: Router, private auth: AuthService, private alertCtrl: AlertController, private toastController: ToastController) {}

	canActivate(route: ActivatedRouteSnapshot): Observable<boolean> {
		if ((this.auth && this.auth.getUser() == undefined) || this.auth.getUserSub == undefined) {
			this.presentToast("Please login with your email and password");
			this.router.navigate(["/login"]);
			return new BehaviorSubject<boolean>(false);
		} else {
			if (this.auth && this.auth.user && this.auth.getUser() != undefined && !this.assertAlive()) {
				this.presentToast("Session has expired");
				this.router.navigate(["/login"]);
				return new BehaviorSubject<boolean>(false);
			} else {
				return new BehaviorSubject<boolean>(true);
			}
		}
	}

	async presentToast(msg) {
		const toast = await this.toastController.create({
			message: msg,
			duration: 2000,
			color: "dark",
		});
		toast.present();
	}

	isLoggin() {
		if ((this.auth && this.auth.getUser() == undefined) || this.auth.getUserSub == undefined) {
			this.presentToast("Please login with your email and password");
			this.router.navigate(["/login"]);
			return false;
		} else {
			if (this.auth && this.auth.user && this.auth.getUser() != undefined && !this.assertAlive()) {
				this.presentToast("Session has expired");
				this.router.navigate(["/login"]);
				return false;
			} else {
				return true;
			}
		}
	}

	assertAlive(): boolean {
		let decoded: any = undefined;
		if (this.auth && this.auth.user && this.auth.getUser() && this.auth.getUser().exp) {
			decoded = this.auth.getUser().exp;
		} else {
			return false;
		}
		const now = Date.now().valueOf() / 1000;
		if (typeof decoded !== "undefined" && decoded < now) {
			console.log(`token expired: ${JSON.stringify(decoded)}`);
			return false;
		}
		if (typeof decoded.nbf !== "undefined" && decoded.nbf > now) {
			console.log(`token not yet valid: ${JSON.stringify(decoded)}`);
			return false;
		}
		return true;
	}
}
