import { Component, OnInit } from "@angular/core";
import { Router, NavigationExtras } from "@angular/router";
import { Storage } from "@ionic/storage";
import { OrdersService } from "../../services/orders.service";
import { Order } from "src/app/interfaces/woo_order";
import { CinemaService } from "../../services/cinema.service";
import { Seat } from "../../interfaces/sql_seats";
import { LocalNotifications } from '@ionic-native/local-notifications/ngx';

@Component({
	selector: "app-card",
	templateUrl: "./card.page.html",
	styleUrls: ["./card.page.scss"],
})
export class CardPage implements OnInit {
	public cards: any;
	order: Order = Object();
	seats_selected: string[] = [];
	limit: number = 2;
	seatT: Seat;
	flag = false;
	fecha_ap : any;

	constructor(private router: Router, private orderService: OrdersService, private storage: Storage, private cinemaService: CinemaService, private localNotifications: LocalNotifications) {
		this.cards = [
			{
				state: "ON",
				logo: "./../../../assets/img/card/visa.png",
				a: 1234,
				b: 5522,
				c: 8432,
				d: 2264,
				expires: "7/12",
				name: "Jerry Smith",
			},
		];
	}
	ngOnInit() {}

	localNotif(fecha : string) {

		let horaCompleta = fecha.split(" ")[1];
		let hora = Number(horaCompleta.split(":")[0]);
		let min = Number(horaCompleta.split(":")[1]);
		//let min = Number("40"); // Esta para poner el minuto y hacer pruebas
		hora -= 1;

		let mes = Number(fecha.split("-")[1])-1;
		let ano = Number(fecha.split("-")[0]);
		let diaString = fecha.split("-")[2];
		let dia = Number(diaString.split(" ")[0]);

    this.localNotifications.schedule({
      id: 1,
			title: 'Reminder',
      text: 'Your movie starts in 1 hour',
			trigger: { at: new Date(ano, mes, dia, hora, min) },
      data: { secret: 'secret' }
    });

  }

	goToTicket() {
		this.storage.get("auth").then((auth) => {
			if (auth) {
				this.order.payment_method = "bacs";
				this.order.payment_method_title = "Direct Bank Transfer";
				this.order.set_paid = true;
				this.order.customer_id = auth.id;
				this.order.billing = {
					first_name: auth.username,
					last_name: "",
					address_1: "",
					address_2: "",
					city: "",
					state: "",
					postcode: "",
					country: "US",
					email: auth.email,
					phone: "",
				};

				// this.order.shipping.first_name = val.username;
				// this.order.shipping.last_name = "";
				// this.order.shipping.address_1 = "";
				// this.order.shipping.address_2 = "";
				// this.order.shipping.city = "";
				// this.order.shipping.state = "";
				// this.order.shipping.postcode = "";
				// this.order.shipping.country = "US";
				this.order.line_items = [];
				let woo_product;

				this.storage
					.get("cart")
					.then((cart) => {
						if (cart.length > 0)
							cart.forEach((element) => {
								if (element.product.variations_desc != undefined && element.product.variations_desc.length > 0) {
									let variation = element.product.variations_desc.find((product, index) => {
										product.attributes[0].option === element.size;
										return index;
									});
									if (variation) {
										woo_product = {
											product_id: element.product.id,
											variation_id: variation.id,
											quantity: element.qty,
										};
									} else {
										woo_product = {
											product_id: element.product.id,
											quantity: element.qty,
										};
									}
								} else {
									woo_product = {
										product_id: element.product.id,
										quantity: element.qty,
									};
								}
								if (woo_product) {
									this.order.line_items.push(woo_product);
								}
							});
					})
					.finally(() => {
						this.storage.get("seats_selected").then((seats_selected) => {
							if (seats_selected) {
								this.storage.get("showtime_selected").then((showtime) => {
									if (showtime) {
										woo_product = {
											product_id: showtime.id,
											quantity: seats_selected.seats.length,
										};
										if (woo_product) {
											this.order.line_items.push(woo_product);
										}
										this.storage.get("jwt").then((jwt) => {
											if (jwt) {
												this.orderService.addOrder(this.order, jwt).subscribe(
													(orders) => {
														this.storage.get("jwt").then((jwt) => {
															this.storage.get("seats_taken").then((seats) => {
																let seatstaken: Seat[] = JSON.parse(seats);
																if (seatstaken != null && Array.isArray(seatstaken)) {
																	seatstaken.forEach((seat) => {
																		this.flag = true;
																		this.seatT = seat;
																		this.fecha_ap = seat.fecha_de_funcion;
																		this.cinemaService
																			.putSeats_Order(jwt, seat.id_pelicula, seat.email, seat.asiento, 1, 1, seat.fecha_de_funcion, orders.id)
																			.subscribe(
																				(val) => {
																					console.log(val);
																					// GENERAR NOTIFICACION LOCAL
																					this.localNotif(this.fecha_ap);
																				},
																				(err) => {
																					console.log(err);
																				}
																			);
																	});
																	this.cinemaService
																		.putSeats_TemporalLock(jwt, this.seatT.id_pelicula, this.seatT.email, this.seatT.fecha_de_funcion)
																		.subscribe(
																			(val) => {},
																			(err) => {
																				console.log(err);
																			}
																		);
																}
															});
														});
													},
													(err) => {
														console.log(err);
													},
													() => {
														let navigationExtras: NavigationExtras = { state: { ticket: "movie" } };
														this.router.navigate(["ticket"], navigationExtras);
													}
												);
											}
										});
									}
								});
							} else {
								this.storage.get("jwt").then((val) => {
									if (val) {
										this.orderService.addOrder(this.order, val);
										let navigationExtras: NavigationExtras = { state: { ticket: "snack" } };
										this.router.navigate(["ticket"], navigationExtras);
									}
								});
							}
						});
					});
			}
		});
	}
}
