import { Component, OnInit } from "@angular/core";
import { Storage } from "@ionic/storage";
import { Shop } from "src/app/interfaces/ts_shop";
import { ShopService } from "../../services/shop.service";
import { AlertController, ModalController } from "@ionic/angular";
import { NavigationExtras, Router } from "@angular/router";
import { Movie } from "../../interfaces/ts_movie";
import { CardPage } from '../card/card.page';

@Component({
	selector: "app-cart",
	templateUrl: "./cart.page.html",
	styleUrls: ["./cart.page.scss"],
})
export class CartPage implements OnInit {
	cartList: any[] = [];
	seatsSelected: any;
	price: any;
	total: number = 0;
	movie: Movie;
	showtime: Showtime;

	constructor(
		private storage: Storage,
		private shopService: ShopService,
		private alertController: AlertController,
		private router: Router,
		public modalController: ModalController
	) {}

	async ngOnInit() {
		this.shopService.getCartData().subscribe((data) => {
			this.cartList = data;
			this.getTotalToPay();
		});

		if (this.cartList.length == 0) {
			await this.storage.get("cart").then((val) => (this.cartList = val));
		}

		await this.storage.get("seats_selected").then((val) => {
			if (val) {
				this.seatsSelected = val.seats;
				this.price = val.price;
			}
		});

		await this.storage.get("cinemaSelected").then((val) => {
			if (val && val.movie) {
				this.showtime = val.showtime;
			}
		});

		await this.storage.get("movie_selected").then((val) => {
			if (val) {
				this.movie = val;
			}
		});

		await this.getTotalToPay();
	}

	removeFromCart(list: any, index: number, storage_name: string) {
		list.splice(index, 1);
		if (storage_name === "cart") {
			this.shopService.publishCartData(list);
			this.cartList = list;
		} else {
			this.shopService.publishSeatsData(list);
			this.seatsSelected = list;
		}
	}

	async editSeatsItem() {
		const alert = await this.alertController.create({
			cssClass: "my-custom-class",
			header: "Confirm!",
			message: "Do you want to change the schedule? Go to 'SHOWTIMES' tab.",
			buttons: [
				{
					text: "Cancel",
					role: "cancel",
					cssClass: "secondary",
					handler: (blah) => {
						console.log("Confirm Cancel: blah");
					},
				},
				{
					text: "Okay",
					handler: () => {
						this.storage.get("cinemaSelected").then((resp) => {
							let navigationExtras: NavigationExtras = { state: resp };
							this.router.navigate(["choose-seat"], navigationExtras);
						});
					},
				},
			],
		});

		await alert.present();
	}

	async editCartItem(list: any, index: number, storage_name: string) {
		const alert = await this.alertController.create({
			cssClass: "my-custom-class",
			header: list[index].product.name,
			subHeader: ""+list[index].size,
			inputs: [
				{
					name: "quantity",
					type: "number",
					value: list[index].qty,
					min: 0,
					max: 100,
				},
			],
			buttons: [
				{
					text: "Cancel",
					role: "cancel",
					cssClass: "secondary",
					handler: () => {
						console.log("Confirm Cancel");
					},
				},
				{
					text: "Ok",
					handler: (resp) => {
						if (resp.quantity != list[index].qty.toString()) {
							list[index].qty = +resp.quantity;
							if (storage_name === "cart") {
								this.shopService.publishCartData(list);
								this.cartList = list;
							}
							if (resp.quantity === "0") {
								this.removeFromCart(list, index, storage_name);
							}
						} else {
							console.log("No changes");
						}
						console.log("Confirm Ok");
					},
				},
			],
		});
		await alert.present();
	}

	async getTotalToPay() {
		this.total = 0;
		if (this.cartList) {
			for (let car of this.cartList) {
				if (car.price) {
					this.total += car.price * car.qty;
				} else {
					this.total += car.product.price * car.qty;
				}
			}
			this.total.toFixed(2);
		}

		if (this.seatsSelected != null && this.seatsSelected.length > 0 && this.price != 0) {
			this.total += this.seatsSelected.length * this.price;
		}
		
	}

	async checkOut() {
		this.storage.set("total",this.total);
		this.router.navigate(['/card']);
	}
}
