import { Component, OnInit } from "@angular/core";
import { Storage } from "@ionic/storage";
import { Router, ActivatedRoute, NavigationExtras } from "@angular/router";
import { LoadingController, ToastController, AlertController, PickerController, NavController, ActionSheetController } from "@ionic/angular";
import { CinemaService } from "../../services/cinema.service";
import { Cinema } from "src/app/interfaces/woo_cinema";
import { ts_CinemaRoom } from "../../interfaces/ts_cinemaRoom";
import { ShopService } from "src/app/services/shop.service";
import { Movie } from "src/app/interfaces/ts_movie";
import { TheatersService } from "src/app/services/theaters.service";
import { Theater } from "src/app/interfaces/ts_cinema";
import { CinemaRoom } from "../../interfaces/woo_cinemaRoom";
import { ModalController } from "@ionic/angular";
import { CalendarModal, CalendarModalOptions, CalendarResult } from "ion2-calendar";
import { DatePipe } from "@angular/common";
import { Shop } from "src/app/interfaces/ts_shop";
import { ShopQuantityPageModule } from "../shop-quantity/shop-quantity.module";
import { ShopQuantityPage } from "../shop-quantity/shop-quantity.page";
import { Seat } from "../../interfaces/sql_seats";

@Component({
	selector: "app-choose-seat",
	templateUrl: "./choose-seat.page.html",
	styleUrls: ["./choose-seat.page.scss"],
})
export class ChooseSeatPage implements OnInit {
	cinema: Cinema;
	cinemas: Cinema[];
	cinema_room: ts_CinemaRoom;
	rows: number[] = [];
	columns: number[] = [];
	maxColumns: number = 0;
	abcColumn: string[] = [];
	seatGrid: string[][] = [];
	unavailable: string[] = [];
	covid: string[] = [];
	seats_selected: string[] = [];
	seats: Seat[] = [];
	cinemaRooms: CinemaRoom[] = [];
	cinemaroom_selected: CinemaRoom;
	theaters: Theater[] = [];
	theaters_temp: Theater[] = [];
	price: number = 0;
	tax: number = 1;
	movie: Movie;
	showtime: Showtime;
	tab_selected: string = "theaters";
	theater_Selected: number = 0;
	showtimes: Showtime[];
	date_from: string = "";
	year_from: string = "";
	year_to: string = "";
	customDayShortNames = ["Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"];
	customPickerOptions: any;
	selectedDate: any = 0;
	myDate = new Date();
	showtime_selected: any = 0;
	jwt: any;
	auth: any;
	cart: any[] = [];
	foodList: Shop[] = [];
	beverageList: Shop[] = [];
	slideOpts = {
		slidesPerView: 2.6,
		freeMode: false,
		spaceBetween: 20,
	};
	selected_seats: boolean = false;
	loadingImage: string = "";
	cinema_rooms_duplicated: any = [];
	cinema_selected: any = 0;
	realQtyCart = 0;
	total: number = 0;
	seats_confirm = false;
	disable_showtime_button = true;
	timeLeft: number = 600;
	timer: string = "";
	timer_started: boolean = false;
	interval;
	limit: number = 2;

	constructor(
		private storage: Storage,
		private router: Router,
		public loadingController: LoadingController,
		private cinemaService: CinemaService,
		private route: ActivatedRoute,
		private toastController: ToastController,
		private alertController: AlertController,
		private shopService: ShopService,
		private theaterService: TheatersService,
		private datePipe: DatePipe,
		public modalCtrl: ModalController,
		private pickerController: PickerController,
		private modalController: ModalController,
		private actionSheetController: ActionSheetController
	) {
		this.route.queryParams.subscribe(() => {
			if (this.router.getCurrentNavigation().extras.state) {
				this.movie = this.router.getCurrentNavigation().extras.state.movie;
			}
		});
		this.date_from = this.datePipe.transform(this.myDate, "yyyy-MM-dd");
		this.year_to = this.datePipe.transform(this.myDate.setMonth(this.myDate.getMonth() + 1), "yyyy-MM-dd");
		this.storage.get("jwt").then((resp) => {
			if (resp) {
				this.jwt = resp;
			}
		});
		this.storage.get("auth").then((resp) => {
			if (resp) {
				this.auth = resp;
			}
		});
	}

	async ngOnInit() {
		const loading = await this.loadingController.create({
			cssClass: "my-custom-class",
			message: "Please wait",
		});
		await loading.present();
		await this.storage.get("theaters").then((val) => {
			if (!val) {
				this.theaterService.getTheaters().subscribe((resp) => {
					this.storage.set("theaters", resp);
					this.theaters_temp = resp;
				});
			} else {
				this.theaters_temp = val;
			}
		});

		await this.storage.get("seats_selected").then((resp) => {
			if (resp && resp.seats && resp.seats.length > 0) {
				this.seats_selected = resp.seats;
			}
		});

		await this.getCinemas(loading);

		await this.storage
			.get("seats_selected")
			.then((val) => (this.selected_seats = val.seats.length != 0))
			.catch(() => (this.selected_seats = false));

		await this.storage.get("cart").then((val) => {
			if (val) {
				for (let product of val) {
					this.realQtyCart += product.qty;
				}
				this.cart = val;
				this.getTotalToPay();
			}
		});

		this.shopService.getCartData().subscribe((data) => {
			this.storage.set("cart", data);
			this.realQtyCart = 0;
			for (let product of data) {
				this.realQtyCart += product.qty;
			}
		});

		await this.storage.get("food").then((val) => {
			if (val) {
				this.foodList = val;
			} else {
				this.shopService.getFood().subscribe((res) => {
					this.foodList = res;
					this.storage.get("jwt").then((resp) => {
						if (resp) {
							this.jwt = resp;
							this.setVariationsToProduct(this.foodList);
						}
					});
				});
			}
		});

		await this.storage.get("beverage").then((val) => {
			if (val) {
				this.beverageList = val;
			} else {
				this.shopService.getBeverage().subscribe((res) => {
					this.beverageList = res;
					this.storage.get("jwt").then((resp) => {
						if (resp) {
							this.jwt = resp;
							this.setVariationsToProductBeverage(this.beverageList);
						}
					});
				});
			}
		});
	}

	// Tabs
	changeTab(tabs: string) {
		if (tabs == "theaters") {
			this.tab_selected = tabs;
		} else if ((tabs == "showtimes" || tabs == "concessions") && this.cinema_selected == 0) {
			this.presentToast("Please select a theater!");
		} else {
			this.tab_selected = tabs;
		}
	}

	async goBack() {
		if (this.seats_selected && this.seats_selected.length > 0) {
			const alert = await this.alertController.create({
				cssClass: "my-custom-class",
				header: "Back to movie detail",
				message: `Seats selected will be reset. Do you want to continue?`,
				buttons: [
					{
						text: "Cancel",
						role: "cancel",
						cssClass: "secondary",
						handler: (blah) => {
							//do nothing
						},
					},
					{
						text: "Okay",
						handler: () => {
							if (this.seats_selected.length > 0) {
								this.seats_selected.forEach((seat) => {
									let date =
										this.datePipe.transform(this.selectedDate, "yyyy-MM-dd").toString() +
										" " +
										this.datePipe
											.transform(this.showtime_selected["toolset-meta"]["campos-personalizados-producto-horario"].showtime.formatted, "H:mm")
											.toString();
									this.cinemaService.putSeats_Release(this.jwt, this.showtime_selected.id, seat, date).subscribe(
										(val) => {
											console.log(val);
										},
										(err) => {
											console.log(err);
										},
										() => {
											this.storage.remove("seats_selected");
											this.router.navigate(["/movie-detail"]);
										}
									);
								});
							}
						},
					},
				],
			});
			await alert.present();
		} else {
			this.router.navigate(["/movie-detail"]);
		}
	}

	async getTotalToPay() {
		this.total = 0;
		if (this.cart) {
			for (let car of this.cart) {
				if (car.price) {
					this.total += car.price * car.qty;
				} else {
					this.total += car.product.price * car.qty;
				}
			}
			this.total.toFixed(2);
		}

		if (this.seats_selected != null && this.seats_selected.length > 0 && this.price != 0) {
			this.total += this.seats_selected.length * this.price;
		}
	}

	setVariationsToProduct(list: Shop[]) {
		let tempList: Shop[] = [];
		for (let i = 0; i < list.length; i++) {
			let temp: Shop = list[i];
			this.shopService.getVariations(this.jwt, list[i].id).subscribe((resp) => {
				temp.variations_desc = resp;
				tempList.push(temp);
			});
		}
		this.foodList = tempList;
	}

	setVariationsToProductBeverage(list: Shop[]) {
		let tempList: Shop[] = [];
		for (let i = 0; i < list.length; i++) {
			let temp: Shop = list[i];
			this.shopService.getVariations(this.jwt, list[i].id).subscribe((resp) => {
				temp.variations_desc = resp;
				tempList.push(temp);
			});
		}
		this.beverageList = tempList;
	}

	// Theaters
	async getCinemas(loading: any) {
		//get thaters list form storage or api
		this.cinemaService.getCinema_byId(this.movie.id).subscribe(
			(resp) => {
				this.cinemas = resp;
				let temps = [];
				for (let theater of this.theaters_temp) {
					for (let cinema of this.cinemas) {
						if (theater.id == cinema.ID) {
							temps.push(theater);
						}
					}
				}
				this.theaters = temps;
				if (this.theaters.length <= 0) {
					this.router.navigate(["/movie-detail"]);
					this.presentToast("There are not more tickets for this movie");
					loading.dismiss();
					return;
				}
			},
			(err) => {
				loading.dismiss();
				console.log(err);
			},
			() => {
				/*if (this.theaters.length > 0) {
					this.storage.get("cinema_previous").then((val) => {
						if (val) {
							this.theater_Selected = val.id;
							this.selectCinema(val);
						}
					});
				}*/
				loading.dismiss();
			}
		);
	}

	async selectCinema(theater: Theater, index?: number) {
		if (this.cinema_selected.id != theater.id && this.seatSelected.length > 0) {
			this.seats_selected = [];
			this.storage.remove("seats_selected");
			this.seats_confirm = false;
		}
		this.storage.set("theater_selected", theater);
		this.theater_Selected = theater.id;
		this.cinema_rooms_duplicated = [];
		this.showtime_selected = 0;
		this.selectedDate = 0;
		this.cinema_selected = theater;
		this.cinema = this.cinemas.find((cinema) => cinema.ID == theater.id);
		const loading = await this.loadingController.create({
			cssClass: "my-custom-class",
			message: "Please wait",
		});
		await loading.present();
		this.cinemaService.getCinemaRooms_byCinemaId(this.cinema.ID.toString()).subscribe((resp) => {
			this.cinemaRooms = resp;
			this.getShowtimes(loading);
		});
	}

	getShowtimes(loading: any) {
		this.cinemaService.getShowtimes(this.jwt).subscribe((resp) => {
			this.showtimes = resp;
			if (this.showtimes) {
				for (let showtime of this.showtimes) {
					showtime["toolset-meta"]["campos-personalizados-producto-horario"].showtime.formatted = new Date(
						showtime["toolset-meta"]["campos-personalizados-producto-horario"].showtime.formatted
					);
					showtime["toolset-meta"]["campos-personalizados-producto-horario"].showtimeend.formatted = new Date(
						showtime["toolset-meta"]["campos-personalizados-producto-horario"].showtimeend.formatted
					);
				}
				try {
					this.showtimes.sort(
						(a, b) =>
							a["toolset-meta"]["campos-personalizados-producto-horario"].showtime.formatted -
							b["toolset-meta"]["campos-personalizados-producto-horario"].showtime.formatted
					);
				} catch (error) {
					console.error(error);
				} finally {
					this.tab_selected = "showtimes";
					loading.dismiss();
				}
			}
		});
	}

	// Showtimes
	async openCalendar() {
		const loading = await this.loadingController.create({
			cssClass: "my-custom-class",
			message: "Please wait",
		});

		const options: CalendarModalOptions = {
			title: "SELECT A DATE",
			color: "danger",
		};

		let myCalendar = await this.modalCtrl.create({
			component: CalendarModal,
			componentProps: { options },
		});

		await myCalendar.present();
		const event: any = await myCalendar.onDidDismiss();
		this.selectedDate = event.data.dateObj;
		this.storage.set("selected_date", event.data.dateObj);
		if (this.selectedDate !== 0) {
			this.seats_selected = [];
		}
		if (this.showtime_selected) {
			this.showtime_selected = 0;
		}
		await loading.present();
		await this.SetShowtimeToCinemaRoom(loading);
	}

	async SetShowtimeToCinemaRoom(loading: any) {
		this.disable_showtime_button = true;
		for (let cinema_room of this.cinemaRooms) {
			cinema_room.showtime = [];
		}
		if (this.showtimes)
			for (let showtime of this.showtimes) {
				for (let cinema_room of this.cinemaRooms) {
					if (
						showtime["toolset-meta"]["campos-personalizados-producto-horario"].showtimeend.formatted >= new Date() &&
						new Date(this.selectedDate) <= showtime["toolset-meta"]["campos-personalizados-producto-horario"].showtimeend.formatted &&
						cinema_room.ID == showtime["toolset-meta"]["campos-personalizados-producto-horario"].sala.raw &&
						this.datePipe.transform(this.selectedDate, "YYYY-MM-DD") >=
							this.datePipe.transform(showtime["toolset-meta"]["campos-personalizados-producto-horario"].showtime.formatted, "YYYY-MM-DD") &&
						this.movie.id == showtime["toolset-meta"]["campos-personalizados-producto-horario"]["pelicula-horario"].raw
					) {
						cinema_room.showtime = cinema_room.showtime == null ? [] : cinema_room.showtime;
						cinema_room.showtime.push(showtime);
						this.disable_showtime_button = false;
					}
				}
				await loading.dismiss();
			}
		if (this.disable_showtime_button) {
			const toast = await this.toastController.create({
				message: "No results were found",
				duration: 1000,
				color: "dark",
				cssClass: "toast",
			});
			toast.present();
			await loading.dismiss();
		}
	}

	async showTimePicker() {
		let picker = await this.pickerController.create({
			buttons: [
				{
					text: "Cancel",
					role: "cancel",
				},
				{
					text: "Ok",
					handler: (resp: any) => {
						this.seats_selected = [];
						if (this.cinema_rooms_duplicated && this.cinema_rooms_duplicated.length > 0) {
							let val = this.datePipe
								.transform(
									this.cinema_rooms_duplicated[0].showtime[0]["toolset-meta"]["campos-personalizados-producto-horario"].showtime.formatted,
									"H:mm"
								)
								.toString();
							let val2 = this.datePipe
								.transform(resp.time.value["toolset-meta"]["campos-personalizados-producto-horario"].showtime.formatted, "H:mm")
								.toString();

							if (val !== val2) {
								this.cinema_rooms_duplicated = [];
							}
						}
						this.showtime_selected = resp.time.value;
						this.price = resp.time.value.price;
						this.storage.set("showtime_selected", resp.time.value);

						if (this.cinema_rooms_duplicated.length == 0) {
							this.setColumnNumberToLetter();
						}
					},
				},
			],
			columns: [
				{
					name: "time",
					options: this.getShowtimeColumnOptions(),
				},
			],
		});
		picker.present();
	}

	async setColumnNumberToLetter() {
		const loading = await this.loadingController.create({
			cssClass: "my-custom-class",
			message: "Please wait",
		});
		await loading.present();

		let columns = +this.cinema_selected["toolset-meta"]["campos-personalizados-cines"]["columnas"].raw;
		let rows = +this.cinema_selected["toolset-meta"]["campos-personalizados-cines"]["filas"].raw;
		let selected_ts_cinema: CinemaRoom; // = cinemasTemp.find((cinema) => (cinema.showtime = this.showtime_selected));

		let tempSeat: Seat[] = [];
		let date =
			this.datePipe.transform(this.selectedDate, "yyyy-MM-dd").toString() +
			" " +
			this.datePipe
				.transform(this.showtime_selected["toolset-meta"]["campos-personalizados-producto-horario"].showtime.formatted, "H:mm")
				.toString() +
			":00";
		this.cinemaService.getSeats(this.jwt, this.showtime_selected.id, date).subscribe((val) => {
			this.seats = val;
			val.forEach((seat) => {

				if (seat.vendido === "1" || seat.email === "unavailable" || (seat.email !== this.auth.email && seat.temporal === "1")) {
					this.unavailable.push(seat.asiento);
					if (seat.email === "unavailable"){
						this.covid.push(seat.asiento);
					}
				} else {
					if (this.auth.email === seat.email && seat.temporal !== "1") {
						this.seats_selected.push(seat.asiento);
						this.shopService.publishSeatsData({ seats: this.seats_selected, price: this.price });
						tempSeat.push(seat);
						this.storage.set("seats_taken", JSON.stringify(tempSeat));
						this.getTotalToPay();
					} else {
						if (seat.email !== "available" && seat.email !== this.auth.email) this.unavailable.push(seat.asiento);
					}
				}
			});
		});



		this.cinemaRooms.forEach((cinema) => {
			cinema.showtime.forEach((showtime) => {
				if (showtime.id == this.showtime_selected.id) {
					selected_ts_cinema = cinema;
				}
			});
		});

		this.cinemaService.getTsCinemaRoom_byId(selected_ts_cinema.ID.toString()).subscribe((val) => {
			if (val) {
				this.unavailable = val["toolset-meta"]["campos-personalizados-salas"]["asientos-no-disponibles"].raw;
				this.unavailable.forEach((un_seat) => {
					this.cinemaService.putSeats_Taken(this.jwt, this.showtime_selected.id, "unavailable", un_seat, 0, 0, date).subscribe(
						(val) => {},
						(err) => {
							console.log(err);
						}
					);
				});
			}

			this.maxColumns = columns;

			for (let r = 0; r < rows; r++) {
				this.rows[r] = r + 1;
				this.abcColumn[r] = String.fromCharCode(65 + r);
				this.seatGrid[r] = [];
				for (let c = 0; c < columns; c++) {
					this.columns[c] = c + 1;
					this.seatGrid[r][c] = String.fromCharCode(65 + r) + "" + (c + 1);
				}
			}

			loading.dismiss();
		});


	}

	getShowtimeColumnOptions() {
		let options = [];
		this.cinema_rooms_duplicated = [];
		this.showtime_selected = 0;
		let flag: Boolean = false;
		for (let cinemaroom of this.cinemaRooms) {
			if (cinemaroom.showtime && cinemaroom.showtime.length > 0) {
				flag = false;
				for (let showtime of cinemaroom.showtime) {
					if (options.length > 0) {
						let optValue: any;
						options.some((opt) => {
							if (
								opt.text ===
								this.datePipe.transform(showtime["toolset-meta"]["campos-personalizados-producto-horario"].showtime.formatted, "hh:mma").toString()
							) {
								optValue = opt.value;
								flag = true;
								return;
							}
						});
						if (flag) {
							this.cinema_rooms_duplicated.push(cinemaroom);
							const cinemaroomtemp = this.cinemaRooms.find(
								(cinema) => cinema.ID == optValue["toolset-meta"]["campos-personalizados-producto-horario"].sala.raw
							);
							this.cinema_rooms_duplicated.push(cinemaroomtemp);
						} else {
							options.push({
								text: this.datePipe.transform(showtime["toolset-meta"]["campos-personalizados-producto-horario"].showtime.formatted, "hh:mma"),
								value: showtime,
							});
						}
					} else {
						options.push({
							text: this.datePipe.transform(showtime["toolset-meta"]["campos-personalizados-producto-horario"].showtime.formatted, "hh:mma"),
							value: showtime,
						});
					}
				}
			}
		}

		return options;
	}

	async selectCinemaRoom() {
		let picker = await this.pickerController.create({
			buttons: [
				{
					text: "Cancel",
					role: "cancel",
				},
				{
					text: "Ok",
					handler: (resp: any) => {
						this.cinemaroom_selected = resp.cinema_room.value;
						this.setColumnNumberToLetter();
					},
				},
			],
			columns: [
				{
					name: "cinema_room",
					options: this.getColumnOptionsCinemas(),
				},
			],
		});
		picker.present();
	}

	getColumnOptionsCinemas() {
		let options = [];
		for (let cinema of this.cinema_rooms_duplicated) {
			options.push({ text: cinema.post_title, value: cinema });
		}
		return options;
	}

	async gotToShop() {
		this.cinemaService.putDisableSeats(this.showtime_selected, this.jwt).subscribe(
			(val) => {
				console.log(val);
			},
			(err) => {
				console.log(err);
			}
		);

		if (this.seats_selected.length <= 0) {
			const toast = await this.toastController.create({
				message: "You haven't selected any seat yet.",
				duration: 1000,
				color: "dark",
				cssClass: "toast",
			});
			toast.present();
		} else {
			if (!this.seats_confirm) {
				const alert = await this.alertController.create({
					cssClass: "my-custom-class",
					header: "Confirm seating location",
					message: `You have selected <strong> ${this.getSeatList()} </strong> seat(s). Is this correct?`,
					buttons: [
						{
							text: "Cancel",
							role: "cancel",
							cssClass: "secondary",
							handler: (blah) => {
								//do nothing
							},
						},
						{
							text: "Okay",
							handler: () => {
								this.seats_confirm = true;
								this.storage.set("seats_selected", { seats: this.seats_selected, price: this.price });
								this.shopService.publishSeatsData({ seats: this.seats_selected, price: this.price });
								this.changeTab("concessions");
							},
						},
					],
				});

				await alert.present();
			} else {
				this.changeTab("concessions");
			}
		}
	}

	seatSelected(seatNum: string) {
		let date =
			this.datePipe.transform(this.selectedDate, "yyyy-MM-dd").toString() +
			" " +
			this.datePipe
				.transform(this.showtime_selected["toolset-meta"]["campos-personalizados-producto-horario"].showtime.formatted, "H:mm")
				.toString() +
			":00";
		this.cinemaService.getSeats_Unavailables(this.jwt, this.showtime_selected.id, date).subscribe((val) => {
			if (val) {
				val.forEach((seat) => {
					if (seat.email !== this.auth.email && this.unavailable.indexOf(seatNum) === -1 && seat.email !== "available") {
						this.unavailable.push(seat.asiento);
					}
				});
			}

			if (this.unavailable.indexOf(seatNum) === -1) {
				this.seats_confirm = false;
				let index = this.seats_selected.indexOf(seatNum);
				if (index !== -1) {
					this.seats_taken_Temporal_Logic(date, "release");
					this.cinemaService.putSeats_Release(this.jwt, this.showtime_selected.id, this.seats_selected[index], date).subscribe(
						(val) => {
							this.seats_taken_Temporal_Logic(date, "taken");
						},
						(err) => {
							console.log(err);
						}
					);
					this.seats_selected.splice(index, 1);

					if (this.seats_selected.length === 0) {
						this.timeLeft = 600;
						this.pauseTimer();
					}
				} else {
					this.seats_selected.push(seatNum);
					if (this.seats_selected.length > 0 && !this.timer_started) {
						this.startTimer();
					}

					let tempSeat: Seat[] = [];
					this.seats_taken_Temporal_Logic(date, "taken");

					this.seats_selected.forEach((seat) => {
						this.cinemaService.putSeats_Taken(this.jwt, this.showtime_selected.id, this.auth.email, seatNum, 0, 1, date).subscribe(
							(val) => {},
							(err) => {},
							() => {
								this.cinemaService.getSeats(this.jwt, this.showtime_selected.id, date).subscribe((seats) => {
									for (let seat of seats) {
										if (this.auth.email === seat.email && seat.vendido !== "1" && seat.apartado === "1") {
											if (tempSeat.length == 0 || tempSeat.find((seat2) => seat2.asiento === seat.asiento) == undefined) {
												tempSeat.push(seat);
												this.storage.set("seats_taken", JSON.stringify(tempSeat));
											}
										}
									}
								});
							}
						);
					});
				}

				this.shopService.publishSeatsData({ seats: this.seats_selected, price: this.price });
				this.getTotalToPay();
			} else {
				this.presentToast("This seat is not available at the moment");
			}
		});
	}

	seats_taken_Temporal_Logic(date: string, status: string) {
		this.seats_selected.sort();

		for (let i = +this.seats_selected[0].substr(1, 2) - 1, limit = this.limit; i > 0 && limit > 0; i--, limit--) {
			if (
				this.unavailable.indexOf(this.seats_selected[0].substr(0, 1) + i) === -1 &&
				this.seats_selected.indexOf(this.seats_selected[0].substr(0, 1) + i) === -1
			) {
				//console.log(this.seats_selected[0].substr(0, 1) + i);
				this.seats_take_temporal(this.seats_selected[0].substr(0, 1) + i, date, status);
			}
		}

		for (
			let i = +this.seats_selected[this.seats_selected.length - 1].substr(1, 2) + 1, limit = this.limit;
			i <= this.maxColumns && limit > 0;
			i++, limit--
		) {
			if (
				this.unavailable.indexOf(this.seats_selected[0].substr(0, 1) + i) === -1 &&
				this.seats_selected.indexOf(this.seats_selected[0].substr(0, 1) + i) === -1
			) {
				//console.log(this.seats_selected[0].substr(0, 1) + i);
				this.seats_take_temporal(this.seats_selected[0].substr(0, 1) + i, date, status);
			}
		}
	}

	seats_take_temporal(seatNum: string, date: string, status: string) {
		if (status === "release") {
			this.cinemaService.putSeats_TemporalTaken(this.jwt, this.showtime_selected.id, "available", seatNum, 0, 0, 0, date).subscribe(
				(val) => {},
				(err) => {
					console.log(err);
				}
			);
		} else {
			this.cinemaService.putSeats_TemporalTaken(this.jwt, this.showtime_selected.id, this.auth.email, seatNum, 0, 0, 1, date).subscribe(
				(val) => {},
				(err) => {
					console.log(err);
				}
			);
		}
	}

	startTimer() {
		this.presentToast("You have 10 minutes to end your transaction, thank you");
		this.timer_started = true;
		this.interval = setInterval(() => {
			if (this.timeLeft > 0) {
				this.timeLeft--;
				const minutes: number = Math.floor(this.timeLeft / 60);
				this.timer = minutes.toString().padStart(2, "0") + ":" + (this.timeLeft - minutes * 60).toString().padStart(2, "0");
				if (this.timeLeft === 0) {
					this.seats_selected.forEach((seat) => {
						let date =
							this.datePipe.transform(this.selectedDate, "yyyy-MM-dd").toString() +
							" " +
							this.datePipe
								.transform(this.showtime_selected["toolset-meta"]["campos-personalizados-producto-horario"].showtime.formatted, "H:mm")
								.toString();
						this.cinemaService.putSeats_Release(this.jwt, this.showtime_selected.id, seat, date).subscribe(
							(val) => {
								console.log(val);
							},
							(err) => {
								console.log(err);
							},
							() => {
								this.storage.remove("seats_selected");
								this.presentToast("Transaction time is over");
								this.router.navigate(["/movie-detail"]);
							}
						);
					});
				}
			} else {
				this.timeLeft = 600;
			}
		}, 1000);
	}

	pauseTimer() {
		this.timer_started = false;
		clearInterval(this.interval);
	}

	isSelected(seatNum: string) {
		return this.seats_selected.includes(seatNum);
	}

	getSeatList() {
		let seats = "";
		for (let i = 0; i < this.seats_selected.length; i++) {
			if (i == 0) {
				seats += this.seats_selected[i];
			} else {
				seats += ", " + this.seats_selected[i];
			}
		}
		return seats;
	}

	isAvailable(seatNum: string) {
		for (let seat of this.unavailable) {
			if (seatNum === seat) {
				return false;
			}
		}
		return true;
	}

	isCovid(seatNum: string) {
		for (let seat of this.covid) {
			if (seatNum === seat) {
				return false;
			}
		}
		return true;
	}

	// Shop
	goToCart() {
		this.router.navigate(["cart"]);
	}

	async addToShoppingModal(shopping: Shop) {
		const modal: HTMLIonModalElement = await this.modalController.create({
			component: ShopQuantityPageModule,
			componentProps: {
				product: shopping,
			},
		});

		modal.onDidDismiss().then((detail) => {
			if (detail !== null) {
				console.log("The result:", detail.data);
			}
		});

		await modal.present();
	}

	async addToShopping(shopping: Shop) {
		const modal = await this.modalController.create({
			component: ShopQuantityPage,
			cssClass: "my-custom-modal-css",
			componentProps: {
				product: shopping,
			},
		});

		modal.onDidDismiss().then((detail) => {
			if (detail !== null && detail.data !== null) {
				console.log("The result:", detail.data);
				this.addToCart(shopping, detail.data.size, detail.data.quantity);
			}
		});

		await modal.present();
	}

	async addToCart(shopping: Shop, size: string, quantity: number) {
		let flag: Boolean = true;

		const toast = await this.toastController.create({
			message: size != "" ? `${shopping.name} (${size}) have been added to cart` : `${shopping.name} have been added to cart`,
			duration: 1000,
			animated: true,
			color: "dark",
			cssClass: "toast",
		});
		toast.present();

		if (this.cart.length > 0) {
			this.cart.some((shop, index) => {
				if (shop.product.id === shopping.id && shop.size === size) {
					this.cart[index] = {
						product: shop.product,
						qty: shop.qty + quantity,
						size: size,
					};
					flag = false;
					return;
				}
			});
			if (flag) {
				this.cart.push({
					product: shopping,
					qty: quantity,
					size: size,
				});
			}
		} else {
			this.cart.push({
				product: shopping,
				qty: quantity,
				size: size,
			});
		}
		await this.storage.set("cart", this.cart);
		this.shopService.publishCartData(this.cart);
		this.getTotalToPay();
	}

	async presentToast(message: string) {
		const toast = await this.toastController.create({
			message: message,
			duration: 2000,
		});
		toast.present();
	}
}
