import { Component, OnInit } from "@angular/core";
import { MoviesService } from "src/app/services/movies.service";
import { Movie } from "src/app/interfaces/ts_movie";
import { LoadingController } from "@ionic/angular";
import { Router, NavigationExtras } from "@angular/router";
import { Storage } from "@ionic/storage";
import { TheatersService } from "../../services/theaters.service";
import { DatePipe } from "@angular/common";
import { BannerService } from "../../services/banner.service";
import { AuthService } from "../../services/auth.service";

@Component({
	selector: "app-tab1",
	templateUrl: "tab1.page.html",
	styleUrls: ["tab1.page.scss"],
})
export class Tab1Page implements OnInit {
	currentMovies: Movie[] = [];
	banners: Banner[] = [];

	slideOpts = {
		slidesPerView: 1,
		pagination: true,
	};

	constructor(
		private movieService: MoviesService,
		private router: Router,
		private storage: Storage,
		public loadingController: LoadingController,
		private theaterService: TheatersService,
		private datePipe: DatePipe,
		private bannerService: BannerService
	) {
		this.storage.remove("cart");
		this.storage.remove("seats_selected");
		this.storage.remove("seats_taken");
		this.storage.remove("theater_selected");
		this.storage.remove("showtime_selected");
		this.storage.remove("movie_selected");
		this.storage.remove("selected_date");
		this.storage.remove("cinemaSelected");
	}

	async ngOnInit() {
		const loading = await this.loadingController.create({
			cssClass: "my-custom-class",
			message: "Please wait",
		});
		await loading.present();

		// await this.storage.get("lastUpdate").then(
		// 	(val) => {
				// if (val && val != this.datePipe.transform(new Date(), "yyyy-MM-dd")) {
					// this.storage.set("lastUpdate", this.datePipe.transform(new Date(), "yyyy-MM-dd"));
					this.getMovies_loadingapi(loading);
					this.getTheaters_api();
					this.getBanners_api();
				// } else {
					// this.storage.set("lastUpdate", this.datePipe.transform(new Date(), "yyyy-MM-dd"));
					// this.storage.get("currentMovies").then((val) => {
					// 	this.getMovies_loadingapi(loading);
					// });
					// this.storage.get("banners").then((ban) => {
					// 	if (ban) {
					// 		this.banners = ban;
					// 	} else {
					// 		this.getBanners_api();
					// 	}
					// });
					// this.storage.get("theaters").then((the) => {
					// 	if (!the) {
					// 		this.getTheaters_api();
				// 		}
				// 	});
				// }
			// },
			// (err: Error) => {
			// 	console.log(err);
			// }
		// );
	}

	getMovies_loadingapi(loading: any) {
		this.movieService.getMovies().subscribe((resp) => {
			this.currentMovies = resp;
			this.storage.set("currentMovies", this.currentMovies);
			loading.dismiss();
		});
	}

	getMovies_api() {
		this.movieService.getMovies().subscribe((resp) => {
			this.currentMovies = resp;
			this.storage.set("currentMovies", this.currentMovies);
		});
	}

	async getMovieDetail(movie: Movie) {
		let navigationExtras: NavigationExtras = { state: { movie: movie } };
		this.router.navigate(["movie-detail"], navigationExtras);
	}

	doRefresh(event) {
		this.storage.set("lastUpdate", this.datePipe.transform(new Date(), "yyyy-MM-dd"));
		this.getTheaters_api();
		this.getMovies_api();
		setTimeout(() => {
			event.target.complete();
		}, 2000);
	}

	getTheaters_api() {
		this.theaterService.getTheaters().subscribe((resp) => {
			this.storage.set("theaters", resp);
		});
	}

	getBanners_api() {
		this.bannerService.getBanners().subscribe((resp) => {
			this.storage.set("banners", resp);
			this.banners = resp;
		});
	}

	authentication() {
		this.router.navigate(["/login"]);
	}

	goToMovies() {
		this.router.navigate(["/tabs/tab2"]);
	}

	slidesDidLoad(slides) {
		slides.startAutoplay();
	}
}
