import { Component, OnInit, Input, ViewChild, PipeTransform } from "@angular/core";
import { YoutubeVideoPlayer } from "@ionic-native/youtube-video-player/ngx/";
import { YtService } from "../../services/yt.service";
import { Movie } from "src/app/interfaces/ts_movie";
import { Storage } from "@ionic/storage";
import { DatePipe } from "@angular/common";
import { AlertController, IonContent, LoadingController, ToastController } from "@ionic/angular";
import { ActivatedRoute, Router, NavigationExtras } from "@angular/router";
import { CinemaService } from "../../services/cinema.service";
import { Cinema } from "src/app/interfaces/woo_cinema";
import { CinemaRoom } from "../../interfaces/woo_cinemaRoom";
import { ts_CinemaRoom } from "src/app/interfaces/ts_cinemaRoom";
import { SocialSharing } from '@ionic-native/social-sharing/ngx';

@Component({
	selector: "app-movie-detail",
	templateUrl: "./movie-detail.page.html",
	styleUrls: ["./movie-detail.page.scss"],
})
export class MovieDetailPage implements OnInit {
	@ViewChild("content", { static: false }) content: IonContent;
	selectedDate: any = null;
	cinemaSelected: string;
	ts_cinema: ts_CinemaRoom;
	movie: Movie;
	cinemaRoom: CinemaRoom[] = [];
	YTvideo: youTubevideo;
	showtimes: Showtime[];
	video: Item;

	synopsis = 100;
	buyTicket: boolean = false;
	ticketPrice: number = 0;

	star1: string = 'star';
	star2: string = 'star';
	star3: string = 'star-half';
	star4: string = 'star-outline';
	star5: string = 'star-outline';

	constructor(
		private youtube: YoutubeVideoPlayer,
		private ytService: YtService,
		private cinemaService: CinemaService,
		private storage: Storage,
		private datePipe: DatePipe,
		private route: ActivatedRoute,
		private router: Router,
		public alertController: AlertController,
		public loadingController: LoadingController,
		private socialSharing: SocialSharing,
		private toastController: ToastController
	) {
		this.route.queryParams.subscribe(() => {
			if (this.router.getCurrentNavigation().extras.state) {
				this.movie = this.router.getCurrentNavigation().extras.state.movie;
			} else {
				this.storage.get("movie_selected").then((val) => (this.movie = val));
			}
		});
	}

	ngOnInit() {
		//get Youtube video data
		this.ytService.getVideo(this.getYoutubevideo_id(this.movie["toolset-meta"]["campos-personalizados-peliculas"].trailer.raw)).subscribe((resp) => {
			this.YTvideo = resp;
			this.video = resp.items[0];
		});
	}

	openVideo() {
		this.youtube.openVideo(this.getYoutubevideo_id(this.movie["toolset-meta"]["campos-personalizados-peliculas"].trailer.raw));
	}

	hideShowSynopsis() {
		if (this.synopsis == 100) {
			this.synopsis = 3000;
		} else {
			this.synopsis = 100;
		}
	}

	getYoutubevideo_id(link: string): string {
		let url_1: string = "https://www.youtube.com/watch?v=";
		let url_2: string = "https://youtu.be/";

		if (link.includes(url_1)) {
			return link.replace(url_1, "");
		}
		if (link.includes(url_2)) {
			return link.replace(url_2, "");
		}
		return link;
	}

	async chooseYourSeat() {
		this.storage.set("seats_selected", []);
		this.storage.set("movie_selected", this.movie);
		this.storage.set("cinemaSelected", { movie: this.movie });
		let navigationExtras: NavigationExtras = { state: { movie: this.movie } };

		this.router.navigate(["choose-seat"], navigationExtras);
	}

	buyTickets() {
		this.buyTicket = true;
		setTimeout(() => {
			if (this.content != null) {
				this.content.scrollToBottom();
			}
		}, 100);
	}

	gotoTab(tab: string) {
		this.router.navigate([`tabs/${tab}`]);
	}

	share(socialmedia : string){
		let movieURL = this.movie["toolset-meta"]["campos-personalizados-peliculas"].trailer.raw;

		if (socialmedia =="whatsapp"){
			this.socialSharing.shareViaWhatsApp("Hey you gotta watch this! Shared through 360Cinema App", null, movieURL).then((res) => {
				  // Success
			}).catch((e) => {
				  // Error!
					this.presentToast("There was an error sharing re-install Whastapp and try again");
			});
		} else if (socialmedia =="facebook"){
			this.socialSharing.shareViaFacebook("Hey you gotta watch this! Shared through 360Cinema App", null, movieURL).then((res) => {
			  // Success
			}).catch((e) => {
			  // Error!
				this.presentToast("There was an error sharing re-install Facebook App and try again");
			});
		} else if (socialmedia =="twitter"){
			this.socialSharing.shareViaTwitter("Hey you gotta watch this! Shared through 360Cinema App", null, movieURL).then((res) => {
			  // Success
			}).catch((e) => {
			  // Error!
				this.presentToast("There was an error sharing re-install Twitter App and try again");
			});
		}else if (socialmedia =="instagram"){
			this.socialSharing.shareViaInstagram("Hey you gotta watch this! Shared through 360Cinema App", this.movie['toolset-meta']['campos-personalizados-peliculas']['poster-pelicula'].raw).then((res) => {
			  // Success
			}).catch((e) => {
			  // Error!
				this.presentToast("There was an error sharing re-install Twitter App and try again");
			});
		}
	}

	rate(star: number){
		this.star1 = 'star-outline';
		this.star2 = 'star-outline';
		this.star3 = 'star-outline';
		this.star4 = 'star-outline';
		this.star5 = 'star-outline';

		if (star == 1){
			this.star1 = 'star';
		}else if (star == 2){
			this.star1 = 'star';
			this.star2 = 'star';
		}else if (star == 3){
			this.star1 = 'star';
			this.star2 = 'star';
			this.star3 = 'star';
		}else if (star == 4){
			this.star1 = 'star';
			this.star2 = 'star';
			this.star3 = 'star';
			this.star4 = 'star';
		}else if (star == 5){
			this.star1 = 'star';
			this.star2 = 'star';
			this.star3 = 'star';
			this.star4 = 'star';
			this.star5 = 'star';
		}

	}

	async presentToast(message: string) {
		const toast = await this.toastController.create({
			message: message,
			duration: 2000,
		});
		toast.present();
	}

}
