import { Component, OnInit } from "@angular/core";
import { MoviesService } from "src/app/services/movies.service";
import { Movie } from "src/app/interfaces/ts_movie";
import { Router, NavigationExtras } from "@angular/router";
import { Storage } from "@ionic/storage";
import { LoadingController } from "@ionic/angular";
import { Theater } from "../../interfaces/ts_cinema";

@Component({
	selector: "app-tab2",
	templateUrl: "tab2.page.html",
	styleUrls: ["tab2.page.scss"],
})
export class Tab2Page implements OnInit {
	currentMovies: Movie[] = [];
	previous_movie: PreviousMovie[] = [];

	slideOpts = {
		slidesPerView: 1,
		freeMode: false,
	};

	constructor(private movieService: MoviesService, private router: Router, private storage: Storage, public loadingController: LoadingController) {}

	async ngOnInit() {
		
	}

	async ionViewWillEnter(){
		const loading = await this.loadingController.create({
			cssClass: "my-custom-class",
			message: "Please wait",
		});
		await loading.present();

		this.storage.get("lastUpdate").then((val) => {
			if (val) {
				this.storage.get("currentMovies").then((val) => {
					this.currentMovies = val;
					this.storage.get("cinema_previous").then((val) => {
						if (val) {
							this.getMovies_previousCinema(loading, val.id);
						} else {
							loading.dismiss();
						}
					});
				});
			} else {
				this.getMovies_loadingapi(loading);
			}
		});
	}

	getMovies_loadingapi(loading: any) {
		this.movieService.getMovies().subscribe((resp) => {
			this.currentMovies = resp;
			this.storage.set("currentMovies", this.currentMovies);
			this.storage.get("cinema_previous").then((val) => {
				if (val) {
					this.getMovies_previousCinema(loading, val.id);
				}
			});
		});
	}

	getMovies_previousCinema(loading: any, cinema_id: number) {
		this.movieService.getPreviousMovies(cinema_id).subscribe((resp) => {
			this.previous_movie = resp;
			this.getPreviousMovies(loading);
		});
	}
	async getPreviousMovies(loading: any) {
		let temps: any[] = [];
		for (let pMovie of this.previous_movie) {
			if(pMovie.post_type != 'pelicula')
				continue;
			for (let cMovie of this.currentMovies) {
				if (pMovie.ID == cMovie.id) {
					temps.push(cMovie);
				}
			}
		}
		this.currentMovies = temps;
		loading.dismiss();
	}

	async doRefresh(event) {
		this.movieService.getMovies().subscribe((resp) => {
			this.currentMovies = resp;
			this.storage.set("currentMovies", this.currentMovies);
		});
		await event.target.complete();
	}

	async getMovieDetail(movie: Movie) {
		let navigationExtras: NavigationExtras = { state: { movie: movie } };
		this.router.navigate(["movie-detail"], navigationExtras);
	}

	authentication() {
		this.router.navigate(["/login"]);
	}
}
