import { Component, OnInit } from "@angular/core";
import { Storage } from "@ionic/storage";
import { Theater } from "src/app/interfaces/ts_cinema";
import { Movie } from "src/app/interfaces/ts_movie";
import QRCode from "qrcode";
import { LoadingController, ModalController } from "@ionic/angular";
import { TicketDetailPage } from "../ticket-detail/ticket-detail.page";
import { Router } from "@angular/router";
import { AuthService } from "../../services/auth.service";
import { OrdersService } from "../../services/orders.service";
import { Orders } from "../../interfaces/woo_getOrder";
import { CinemaService } from "../../services/cinema.service";
import { MoviesService } from "../../services/movies.service";
import { TheatersService } from "../../services/theaters.service";
import { DatePipe } from "@angular/common";
import { Seat } from "src/app/interfaces/sql_seats";

@Component({
	selector: "app-tab4",
	templateUrl: "./tab4.page.html",
	styleUrls: ["./tab4.page.scss"],
})
export class Tab4Page implements OnInit {
	selected_tab: string = "ticket";
	movie: Movie;
	currentMovies: Movie[] = [];
	selected_date: any = 0;
	theater_selected: Theater;
	seats_selected: any;
	seats: string = "";
	fecha_apartado : any;
	showtime: any;
	checkQRCode: boolean = false;
	code = "some sample string";
	generated = "";
	user: any;
	orderList: Orders[] = [];
	loading: any;

	constructor(
		private storage: Storage,
		public modalController: ModalController,
		private datePipe: DatePipe,
		public loadingController: LoadingController,
		private router: Router,
		private authService: AuthService,
		private orderService: OrdersService,
		private cinemaService: CinemaService,
		private movieService: MoviesService,
		private theatersService: TheatersService
	) {}

	changeTab(tab: string) {
		this.selected_tab = tab;
	}

	ngOnInit() {}
	async ionViewWillEnter() {

		this.loading = await this.loadingController.create({
			cssClass: "my-custom-class",
			message: "Please wait",
		});
		await this.loading.present();

		this.storage.get("auth").then((auth) => {
			if (auth) {
				this.user = auth;
				this.storage.get("jwt").then((jwt) => {
					if (jwt) {
						console.log(auth);
						this.orderService.getOrdersByCustomer(auth.id, jwt).subscribe((orders) => {
							this.orderList = orders;
							this.cinemaService.getShowtimes(jwt).subscribe((showtimes) => {
								this.orderList.forEach((order) => {
									showtimes.forEach((showtime) => {
										order.line_items.forEach((item) => {
											if (item.product_id == showtime.id) {
												order.showtime = showtime;
												order.checkQRCode = false;
												this.movieService.getMovies_byShowtime(showtime.id).subscribe((movieShow) => {
													this.storage.get("currentMovies").then((currentMovies) => {
														currentMovies.forEach((current) => {
															if (movieShow[0].ID === current.id) {
																order.movie = current;
															}
														});
													});
													this.theatersService
														.getTheater_byId(order.showtime["toolset-meta"]["campos-personalizados-producto-horario"]["cine-horario"].raw)
														.subscribe((theater) => {
															order.theater = theater;
														});
													this.cinemaService.getSeats_byOrder(jwt, order.id).subscribe((seats) => {
														console.log(seats);
														this.seats_order(seats, order);
													});
												});
											}
										});
									});
								});
							});
						});
					}
				});
			}
		});
		this.storage.get("showtime_selected").then((val) => (this.showtime = val));
		this.storage.get("selected_date").then((val) => (this.selected_date = val));
		this.storage.get("theater_selected").then((val) => (this.theater_selected = val));
	}

	seats_order(seats: Seat[], order: any) {
		this.seats = "";
		this.fecha_apartado = "";
		for (let i = 0; i < seats.length; i++) {
			if (seats.length - 1 == i) {
				this.seats += seats[i].asiento;
			} else {
				this.seats += seats[i].asiento + " - ";
			}
			this.fecha_apartado = seats[i].fecha_de_funcion;
		}
		order.seats = this.seats;
		order.fecha_apartado = this.fecha_apartado.split(" ")[0];
		order.fecha_apartado = order.fecha_apartado.split("-")[1] +"/"+ order.fecha_apartado.split("-")[2]+"/"+ order.fecha_apartado.split("-")[0];
		this.loading.dismiss();
	}

	displayQrCode(order: Orders) {
		this.process(order);
		return (order.checkQRCode = !order.checkQRCode);
	}

	process(order: Orders) {
		const qrcode = QRCode;
		qrcode.toDataURL(order.id.toString(), { errorCorrectionLevel: "H" }, function (err, url) {
			order.qrcode = url;
		});
	}

	// async showDetails(order: Orders) {
	// 	// const modal = await this.modalController.create({
	// 	// 	componentProps: {
	// 	// 		order: JSON.stringify(order),
	// 	// 	},
	// 	// 	component: TicketDetailPage,
	// 	// 	cssClass: "my-custom-class",
	// 	// 	swipeToClose: true,
	// 	// });
	// 	// return await modal.present();
	// }

	logout() {
		this.authService.publishUser(null);
		this.authService.logout();
	}
}
