import { Component, OnInit, EventEmitter } from "@angular/core";
import { Storage } from "@ionic/storage";
import { ShopService } from "../../services/shop.service";
import { Shop } from "src/app/interfaces/ts_shop";
import { ActionSheetController, LoadingController, ModalController, ToastController, NavController } from "@ionic/angular";
import { Router, NavigationExtras } from "@angular/router";
import { ShopQuantityPageModule } from "../shop-quantity/shop-quantity.module";
import { ShopQuantityPage } from "../shop-quantity/shop-quantity.page";
import { AuthGuard } from "../../guards/auth.guard";

@Component({
	selector: "app-shop",
	templateUrl: "./shop.page.html",
	styleUrls: ["./shop.page.scss"],
})
export class ShopPage implements OnInit {
	cart: any[] = [];
	foodList: Shop[] = [];
	beverageList: Shop[] = [];
	slideOpts = {
		slidesPerView: 2.6,
		freeMode: false,
		spaceBetween: 20,
	};
	selected_seats: boolean = false;
	jwt: any;
	loadingImage: string = "";
	count: number = 0;
	globalLoading: any;

	constructor(
		private storage: Storage,
		private shopService: ShopService,
		public loadingController: LoadingController,
		private router: Router,
		private modalController: ModalController,
		private toastController: ToastController,
		private actionSheetController: ActionSheetController,
		private authguard: AuthGuard
	) {}

	async ngOnInit() {
		const loading = await this.loadingController.create({
			cssClass: "my-custom-class",
			message: "Please wait",
		});
		await loading.present();
		this.globalLoading = loading;
		await this.storage
			.get("seats_selected")
			.then((val) => (this.selected_seats = val.length != 0))
			.catch(() => (this.selected_seats = false));

		await this.storage.get("cart").then((val) => {
			if (val) {
				this.cart = val;
			}
		});

		await this.storage.get("food").then((val) => {
			if (val) {
				this.setVariationsToProduct(val);
			} else {
				this.shopService.getFood().subscribe((res) => {
					this.storage.get("jwt").then((resp) => {
						if (resp) {
							this.jwt = resp;
							this.setVariationsToProduct(res);
						}
					});
				});
			}
		});
		await this.storage.get("beverage").then((val) => {
			if (val) {
				this.setVariationsToProductBeverage(val);
			} else {
				this.shopService.getBeverage().subscribe((res) => {
					this.storage.get("jwt").then((resp) => {
						if (resp) {
							this.jwt = resp;
							this.setVariationsToProductBeverage(res);
						}
					});
				});
			}
		});
	}

	keepLoading() {
		this.count++;
		if (this.foodList.length + this.beverageList.length === this.count) {
			this.globalLoading.dismiss();
		}
	}

	async addToCart(shopping: Shop, size: string, quantity: number) {
		let flag: Boolean = true;

		const toast = await this.toastController.create({
			message: size != "" ? `${shopping.name} (${size}) have been added to cart` : `${shopping.name} have been added to cart`,
			duration: 1000,
			animated: true,
			color: "dark",
			cssClass: "toast",
		});
		toast.present();

		if (this.cart.length > 0) {
			this.cart.some((shop, index) => {
				if (shop.product.id === shopping.id && shop.size === size) {
					this.cart[index] = {
						product: shop.product,
						qty: shop.qty + quantity,
						size: size,
					};
					flag = false;
					return;
				}
			});
			if (flag) {
				this.cart.push({
					product: shopping,
					qty: quantity,
					size: size,
				});
			}
		} else {
			this.cart.push({
				product: shopping,
				qty: quantity,
				size: size,
			});
		}
		await this.storage.set("cart", this.cart);
		this.shopService.publishCartData(this.cart);
	}

	goToCart() {
		this.router.navigate(["cart"]);
	}

	async addToShopping(shopping: Shop) {
		const modal = await this.modalController.create({
			component: ShopQuantityPage,
			cssClass: "my-custom-modal-css",
			componentProps: {
				product: shopping,
			},
		});

		modal.onDidDismiss().then((detail) => {
			if (detail !== null && detail.data !== null) {
				console.log("The result:", detail.data);
				this.addToCart(shopping, detail.data.size, detail.data.quantity);
			}
		});

		await modal.present();
	}

	goToChooseSeat() {
		this.storage.get("cinemaSelected").then((resp) => {
			let navigationExtras: NavigationExtras = { state: resp };
			this.router.navigate(["choose-seat"], navigationExtras);
		});
	}

	setVariationsToProduct(list: Shop[]) {
		for (let i = 0; i < list.length; i++) {
			let temp: Shop = list[i];
			this.shopService.getVariations(this.jwt, list[i].id).subscribe((resp) => {
				temp.variations_desc = resp;
				this.foodList.push(temp);
			});
		}
	}

	setVariationsToProductBeverage(list: Shop[]) {
		for (let i = 0; i < list.length; i++) {
			let temp: Shop = list[i];
			this.shopService.getVariations(this.jwt, list[i].id).subscribe((resp) => {
				temp.variations_desc = resp;
				this.beverageList.push(temp);
			});
		}
	}
}
