import { Component, ElementRef, OnInit, ViewChild } from "@angular/core";
import { Router } from "@angular/router";
import { IonInput, AlertController, ToastController, Platform, NavController, LoadingController } from "@ionic/angular";
import { AuthService } from "../../services/auth.service";
import { Facebook } from "@ionic-native/facebook/ngx";
import { Storage } from "@ionic/storage";
import { AuthGuard } from "../../guards/auth.guard";
import { Location } from '@angular/common';

@Component({
	selector: "app-sign-in",
	templateUrl: "./sign-in.page.html",
	styleUrls: ["./sign-in.page.scss"],
})
export class SignInPage implements OnInit {
	@ViewChild("inputId", { static: false }) inputElement: IonInput;
	scopes: string[];
	isLoggedIn: boolean;
	user: any;
	credentials = {
		email: "", //d.valenciapro@gmail.com
		password: "", //asdasd
	};

	constructor(
		private auth: AuthService,
		private router: Router,
		private authService: AuthService,
		private toastController: ToastController,
		private facebook: Facebook,
		public alertController: AlertController,
		public platform: Platform,
		private loadingController: LoadingController,
		private navController: NavController,
		private storage: Storage,
		private location: Location,
		private authguard: AuthGuard
	) {}

	ngOnInit() {}

	ngAfterViewInit() {
		setTimeout(() => {
			this.inputElement.setFocus();
		}, 400);
		if (this.authguard.assertAlive()) {
			this.location.back();
		}
	}

	goBack(){
		this.location.back();
	}

	register() {
		this.router.navigate(["/sign-up"]);
	}

	forgotPassword() {
		this.router.navigate(["/forgot"]);
	}

	async login() {
		const loading = await this.loadingController.create({
			cssClass: "my-custom-class",
			message: "Please wait...",
		});
		await loading.present();
		this.auth.login(this.credentials).subscribe(
			(response) => {
				loading.dismiss();
				this.navController.back();
			},
			(err) => {
				this.toastMessage("Please check your e-mail or password");
				loading.dismiss();
			}
		);
	}

	async toastMessage(message: string) {
		const toast = await this.toastController.create({
			message: message,
			duration: 1000,
			animated: true,
			color: "dark",
			cssClass: "toast",
		});
		toast.present();
	}

	async siginWithFaceBook() {
		const loading = await this.loadingController.create({
			cssClass: "my-custom-class",
			message: "Please wait...",
		});
		await loading.present();
		await this.facebook
			.login(["email"])
			.then((response) => {
				if (response.status === "connected") {
					try {
						this.authService.facebookLogin(response).subscribe((resp) => {
							this.navController.back();
							loading.dismiss();
						});
					} catch (error) {
						this.toastMessage("There was an issue please try later");
						loading.dismiss();
					}
				} else {
					this.toastMessage("Not logged in by FaceBook");
					loading.dismiss();
				}
			})
			.catch((error) => {
				console.log("Error logging into Facebook", error);
				loading.dismiss();
			});
	}

	public logoutFromFacebook() {
		this.facebook
			.logout()
			.then((response) => {
				console.log("Logged out: ", response);
				this.isLoggedIn = false;
			})
			.catch((error) => {
				console.log("Error logout from Facebook", error);
			});
	}
}
