import { Component, OnInit, ViewChild } from "@angular/core";
import { AuthenticationService } from "src/app/services/authentication.service";
import { ToastController, IonInput, AlertController } from "@ionic/angular";
import { Storage } from "@ionic/storage";
import { Router } from "@angular/router";
import { AuthService } from "../../services/auth.service";

@Component({
	selector: "app-sign-up",
	templateUrl: "./sign-up.page.html",
	styleUrls: ["./sign-up.page.scss"],
})
export class SignUpPage implements OnInit {
	@ViewChild("inputId", { static: false }) inputElement: IonInput;
	username: string = "";
	email: string = "";
	password: string = "";

	constructor(
		private authService: AuthenticationService,
		public toastController: ToastController,
		private router: Router,
		private auth: AuthService,
	) {}

	ngOnInit() {}

	ngAfterViewInit() {
		setTimeout(() => {
			this.inputElement.setFocus();
		}, 400);
	}

	async registerUser() {
		let message: string = "";
		if (this.email != "" && this.password != "" && this.username != "") {
			this.authService.registerUser(this.username, this.email, this.password).subscribe(async (resp) => {
				message = await resp.message;
				const toast = await this.toastController.create({
					message: message,
					duration: 2000,
				});
				toast.present();
				this.toastMessage('User registered successfully');
				this.login();
			});
		}
	}

	login() {
		this.auth.login({ email: this.email, password: this.password }).subscribe(
			(response) => {
				this.router.navigate(["/tabs/tab1"]);				
			},
			(err) => {
				this.toastMessage('There was an issue please try it later');
			}
		);
	}

	async toastMessage(message: string) {
		const toast = await this.toastController.create({
			message: message,
			duration: 1000,
			animated: true,
			color: "dark",
			cssClass: "toast",
		});
		toast.present();
	}


	getUserInfo() {}
}
