import { Component, Input, OnInit } from "@angular/core";
import { Storage } from "@ionic/storage";
import { Shop } from "src/app/interfaces/ts_shop";
import { ShopService } from "../../services/shop.service";
import { AlertController, ModalController } from "@ionic/angular";
import { NavigationExtras, Router } from "@angular/router";
import { Movie } from "../../interfaces/ts_movie";
import { CardPage } from '../card/card.page';
import { Orders } from '../../interfaces/woo_getOrder';

@Component({
  selector: 'app-ticket-detail',
  templateUrl: './ticket-detail.page.html',
  styleUrls: ['./ticket-detail.page.scss'],
})
export class TicketDetailPage implements OnInit {
	@Input() order: string;
	cartList: any[] = [];
	seatsSelected: any;
	price: any;
	total: number = 0;
	movie: Movie;
	showtime: Showtime;
	ordern: Orders;

	constructor(
		private storage: Storage,
		private shopService: ShopService,
		private alertController: AlertController,
		private router: Router,
		public modalController: ModalController
	) { }

	async ngOnInit() {
		this.ordern = JSON.parse(this.order);

		this.shopService.getCartData().subscribe((data) => {
			this.cartList = data;
			this.getTotalToPay();
		});

		if (this.cartList.length == 0) {
			await this.storage.get("cart").then((val) => (this.cartList = val));
		}

		await this.storage.get("seats_selected").then((val) => {
			if (val) {
				this.seatsSelected = val.seats;
				this.price = val.price;
			}
		});

		await this.storage.get("cinemaSelected").then((val) => {
			if (val && val.movie) {
				this.showtime = val.showtime;
			}
		});

		await this.storage.get("movie_selected").then((val) => {
			if (val) {
				this.movie = val;
			}
		});

		await this.getTotalToPay();
	}

	dismiss(){
		this.modalController.dismiss();
	}

	async getTotalToPay() {
		this.total = 0;
		if (this.cartList) {
			for (let car of this.cartList) {
				if (car.price) {
					this.total += car.price * car.qty;
				} else {
					this.total += car.product.price * car.qty;
				}
			}
			this.total.toFixed(2);
		}

		if (this.seatsSelected != null && this.seatsSelected.length > 0 && this.price != 0) {
			this.total += this.seatsSelected.length * this.price;
		}
	}

}
