import { Platform } from "@ionic/angular";
import { Injectable } from "@angular/core";
import { Storage } from "@ionic/storage";
import { BehaviorSubject, Observable, from, of } from "rxjs";
import { take, map, switchMap, catchError } from "rxjs/operators";
import { JwtHelperService } from "@auth0/angular-jwt";
import { HttpClient, HttpHeaders, HttpParams } from "@angular/common/http";
import { Router } from "@angular/router";
import { global_URL } from "src/environments/environment.prod";
import { Subject } from "rxjs/internal/Subject";
import { FacebookLoginResponse } from "@ionic-native/facebook/ngx";
import { throwError } from "rxjs/internal/observable/throwError";

const helper = new JwtHelperService();
const USER = "auth";
const TOKEN_KEY = "jwt";
const headers = new HttpHeaders().append("Content-Type", "application/json");
const url = global_URL;

@Injectable({
	providedIn: "root",
})
export class AuthService {
	public user: Observable<any>;
	public jwt = new BehaviorSubject(null);
	url: string = global_URL;
	private userSub = new Subject<any>();

	constructor(private storage: Storage, private http: HttpClient, private platform: Platform, private router: Router) {
		this.loadStoredToken();
	}

	loadStoredToken() {
		this.storage.get(USER).then((resp) => {
			this.jwt.next(resp);
			this.userSub.next(resp);
		});
	}

	login(credentials: { email: string; password: string }): Observable<UserResponse> {
		try {

			return this.http
				.post(
					`${this.url}/?rest_route=/simple-jwt-login/v1/auth`, //&email=${credentials.email}&password=${credentials.password
					{},
					{ headers: headers, params: new HttpParams().append("email", credentials.email).append("password", credentials.password) }
				)
				.pipe(
					take(1),
					map((res: UserResponse) => {
						return `${res.data.jwt}`;
					}),
					switchMap((token) => {
						let decoded = helper.decodeToken(token);
						this.storage.set(TOKEN_KEY, token);
						this.userSub.next(decoded);
						this.jwt.next(decoded);
						let storageObs = from(this.storage.set(USER, decoded));
						return storageObs;
					}),
					catchError((err) => {
						// console.log("caught mapping error and rethrowing", err);
						return throwError(err);
					})
				);
		} catch (err) {
			return throwError(err);
		}
	}

	getUser() {
		return this.jwt.getValue();
	}

	logout() {
		this.storage.remove(USER).then(() => {
			this.router.navigate(["/tabs/tab1"]);
			this.jwt.next(null);
		});
	}

	facebookLogin(fb_response: FacebookLoginResponse): Observable<any[]> {
		let data: any;
		return this.http.get<any[]>(`${url}/callback2.php?accesstoken=${fb_response.authResponse.accessToken}`).pipe(
			take(1),
			map((res: any) => {
				data = res;
				return `${res}`;
			}),
			switchMap((response) => {
				let decoded = helper.decodeToken(data.jwt);
				console.log(decoded);
				this.storage.set(TOKEN_KEY, data.jwt);
				this.userSub.next(data);

				this.jwt.next(decoded);

				let storageObs = from(this.storage.set(USER, decoded));
				return storageObs;
			})
		);
	}

	publishUser(data: any) {
		this.userSub.next(data);
	}

	getUserSub(): Subject<any> {
		return this.userSub;
	}
}
