import { Injectable } from "@angular/core";
import { HttpClient, HttpHeaders, HttpParams } from "@angular/common/http";
import { Observable } from "rxjs/internal/Observable";
import { ShowtimeCategoryID } from "src/environments/environment";
import { Cinema } from "../interfaces/woo_cinema";
import { CinemaRoom } from "../interfaces/woo_cinemaRoom";
import { ts_CinemaRoom } from "../interfaces/ts_cinemaRoom";
import { global_URL } from "../../environments/environment.prod";
import { catchError, map, switchMap, take } from "rxjs/operators";
import { from, throwError } from "rxjs";
import { Seat } from "../interfaces/sql_seats";

const url = global_URL;

const headers = new HttpHeaders({
	"Content-Type": "application/json",
});

@Injectable({
	providedIn: "root",
})
export class CinemaService {
	constructor(private http: HttpClient) {}

	getCinema(): Observable<Cinema[]> {
		return this.http.get<Cinema[]>(`${url}/wp-json/toolset-views/v2/cines-de-pelicula`);
	}

	getCinema_byId(id: number): Observable<Cinema[]> {
		return this.http.get<Cinema[]>(`${url}/wp-json/toolset-views/v2/cines-de-pelicula/?id-pelicula=${id}`);
	}

	getCinemaRoom(): Observable<CinemaRoom[]> {
		return this.http.get<CinemaRoom[]>(`${url}/wp-json/wp/v2/sala/`);
	}

	getTsCinemaRoom_byId(id: string): Observable<ts_CinemaRoom> {
		return this.http.get<ts_CinemaRoom>(`${url}/wp-json/wp/v2/sala/${id}`);
	}

	getCinemaRooms_byCinemaId(cinema_id: string): Observable<CinemaRoom[]> {
		return this.http.get<CinemaRoom[]>(`${url}/wp-json/toolset-views/v2/salas-de-cine/?id-cine=${cinema_id}`);
	}

	getShowtimes(jwt: string): Observable<Showtime[]> {
		let params = new HttpParams();
		params = params.append("jwt", jwt);
		params = params.append("url", `${url}/wp-json/wc/v3/products`);
		params = params.append("stock_status", "instock");
		params = params.append("category", ShowtimeCategoryID.toString());

		return this.http.get<Showtime[]>(`${url}/jwt_validation.php?`, {
			params: params,
		});
	}

	putDisableSeats(showtime: Showtime, jwt: string) {
		let params = new HttpParams();
		params = params.append("jwt", jwt);
		params = params.append("url", `${url}/wp-json/wc/v3/products/${showtime.id}`);
		params = params.append("update", JSON.stringify(showtime.meta_data));
		return this.http.get<Showtime[]>(`${url}/jwt_validation.php?`, {
			params: params,
		});
	}

	seatAvailable(jwt: string, id: number): Observable<Showtime[]> {
		let params = new HttpParams();
		params = params.append("jwt", jwt);
		params = params.append("url", `${url}/wp-json/wc/v3/products/${id}`);
		params = params.append("stock_status", "instock");
		params = params.append("category", ShowtimeCategoryID.toString());

		return this.http.get<Showtime[]>(`${url}/jwt_validation.php?`, {
			params: params,
		});
	}

	getSeats(jwt: string, pelicula_id: any, fecha_funcion: any): Observable<Seat[]> {
		let urle = `${url}/cinema_seats.php?function=GET&pelicula_id=${pelicula_id}&fecha_funcion=${fecha_funcion}&jwt=${jwt}`;
		return this.http.get<Seat[]>(`${url}/cinema_seats.php?function=GET&pelicula_id=${pelicula_id}&fecha_funcion=${fecha_funcion}&jwt=${jwt}`);
	}

	getSeats_byOrder(jwt: string, ordern: any): Observable<Seat[]> {
		let urle = `${url}/cinema_seats.php?function=GETbyOrder&ordern=${ordern}&jwt=${jwt}`;
		return this.http.get<Seat[]>(`${url}/cinema_seats.php?function=GETbyOrder&ordern=${ordern}&jwt=${jwt}`);
	}

	getSeats_Unavailables(jwt: string, pelicula_id: any, fecha_funcion: any): Observable<Seat[]> {
		let urle = `${url}/cinema_seats.php?function=GETU&pelicula_id=${pelicula_id}&fecha_funcion=${fecha_funcion}&jwt=${jwt}`;
		return this.http.get<Seat[]>(`${url}/cinema_seats.php?function=GETU&pelicula_id=${pelicula_id}&fecha_funcion=${fecha_funcion}&jwt=${jwt}`);
	}

	putSeats_Taken(jwt: string, pelicula_id: any, email: any, asiento: any, vendido: any, apartado:any, fecha_funcion: any): Observable<Seat[]> {
		let urle = `${url}/cinema_seats.php?function=PUT&pelicula_id=${pelicula_id}&fecha_funcion=${fecha_funcion}&jwt=${jwt}&email=${email}&asiento=${asiento}&vendido=${vendido}&apartado=${apartado}`;
		return this.http.get<Seat[]>(`${url}/cinema_seats.php?function=PUT&pelicula_id=${pelicula_id}&fecha_funcion=${fecha_funcion}&jwt=${jwt}&email=${email}&asiento=${asiento}&vendido=${vendido}&apartado=${apartado}`);
	}

	putSeats_TemporalTaken(jwt: string, pelicula_id: any, email: any, asiento: any, vendido: any,  apartado:any, temporal: any, fecha_funcion: any): Observable<Seat[]> {
		let urle = `${url}/cinema_seats.php?function=PUTTemporal&pelicula_id=${pelicula_id}&fecha_funcion=${fecha_funcion}&jwt=${jwt}&email=${email}&asiento=${asiento}&vendido=${vendido}&temporal=${temporal}&apartado=${apartado}`;
		return this.http.get<Seat[]>(`${url}/cinema_seats.php?function=PUTTemporal&pelicula_id=${pelicula_id}&fecha_funcion=${fecha_funcion}&jwt=${jwt}&email=${email}&asiento=${asiento}&vendido=${vendido}&temporal=${temporal}&apartado=${apartado}`);
	}

	putSeats_Release(jwt: string, pelicula_id: any, asiento: any, fecha_funcion: any): Observable<Seat[]> {
		let urle = `${url}/cinema_seats.php?function=PUT&pelicula_id=${pelicula_id}&fecha_funcion=${fecha_funcion}&jwt=${jwt}&email=available&asiento=${asiento}&vendido=0&apartado=0`;
		return this.http.get<Seat[]>(`${url}/cinema_seats.php?function=PUT&pelicula_id=${pelicula_id}&fecha_funcion=${fecha_funcion}&jwt=${jwt}&email=available&asiento=${asiento}&vendido=0&apartado=0`);
	}

	putSeats_Order(jwt: string, pelicula_id: any, email: any, asiento: any, vendido: any, apartado:any, fecha_funcion: any, order: any): Observable<Seat[]> {
		let urle = `${url}/cinema_seats.php?function=PUT&pelicula_id=${pelicula_id}&fecha_funcion=${fecha_funcion}&jwt=${jwt}&email=${email}&ordern=${order}&asiento=${asiento}&vendido=${vendido}&apartado=${apartado}`;
		return this.http.get<Seat[]>(`${url}/cinema_seats.php?function=PUT&pelicula_id=${pelicula_id}&fecha_funcion=${fecha_funcion}&jwt=${jwt}&email=${email}&ordern=${order}&asiento=${asiento}&vendido=${vendido}&apartado=${apartado}`);
	}

	putSeats_TemporalLock(jwt: string, pelicula_id: any, email:string, fecha_funcion: any): Observable<Seat[]> {
		let urle = `${url}/cinema_seats.php?function=LockTemp&pelicula_id=${pelicula_id}&fecha_funcion=${fecha_funcion}&jwt=${jwt}&email=${email}`;
		return this.http.get<Seat[]>(`${url}/cinema_seats.php?function=LockTemp&pelicula_id=${pelicula_id}&fecha_funcion=${fecha_funcion}&jwt=${jwt}&email=${email}`);
	}

}
