import { Injectable } from "@angular/core";
import { HttpClient } from "@angular/common/http";
import { Movie } from "../interfaces/ts_movie";
import { environment, global_URL } from "../../environments/environment.prod";
import { Observable } from "rxjs/internal/Observable";

const url = global_URL;
const apiKey = environment.apikey;

@Injectable({
	providedIn: "root",
})
export class MoviesService {
	constructor(private http: HttpClient) {}

	private executeQuery<T>(query: string) {
		query = url + query;
		query += `&api_key=${apiKey}&language=es&include_image_language=es`;
		return this.http.get<T>(query);
	}

	getMovies(): Observable<Movie[]> {
		return this.http.get<Movie[]>(`${url}/wp-json/wp/v2/pelicula`);
	}

	getMovie_byId(id: string): Observable<Movie> {
		return this.http.get<Movie>(`${url}/wp-json/wp/v2/pelicula/${id}`);
	}

	getMovies_byShowtime(id: number) {
		return this.http.get<any>(`${url}/wp-json/toolset-views/v2/pelicula-de-producto/?id-producto=${id}`);
	}

	getPreviousMovies(cinema_id: number): Observable<PreviousMovie[]> {
		return this.http.get<PreviousMovie[]>(`${url}/wp-json/toolset-views/v2/peliculas-por-cinema/?id-cine=${cinema_id}`);
	}
}
