import { Injectable } from "@angular/core";
import { HttpClient, HttpParams, HttpHeaders, HttpBackend } from "@angular/common/http";
import { Observable } from "rxjs/internal/Observable";
import { shopCategoryID, foodID, beverageID } from "src/environments/environment";
import { Shop } from "../interfaces/ts_shop";
import { consumer_key, consumer_secret, global_URL } from "../../environments/environment.prod";
import { Subject } from "rxjs";
import { Storage } from "@ionic/storage";

const url = global_URL;
const headers = new HttpHeaders({
	"Content-Type": "application/json",
	Authorization: "Basic " + btoa(`${consumer_key}:${consumer_secret}`),
});
@Injectable({
	providedIn: "root",
})
export class ShopService {
	shopCategoryID: number = shopCategoryID;
	foodID: number = foodID;
	beverageID: number = beverageID;
	http: HttpClient;
	realQty: number = 0;
	private cart = new Subject<any>();
	private seats = new Subject<any>();

	constructor(private handler: HttpBackend, private storage: Storage) {
		this.http = new HttpClient(handler);
	}

	publishCartData(data: any) {
		this.cart.next(data);
	}

	getCartData(): Subject<any> {
		return this.cart;
	}

	publishSeatsData(data: any) {
		this.seats.next(data);
	}

	getSeatsData(): Subject<any> {
		return this.seats;
	}

	getShop(): Observable<Shop[]> {
		return this.http.get<Shop[]>(`${url}/wp-json/wc/v3/products/?`, { headers });
	}

	getFood(): Observable<Shop[]> {
		let params = new HttpParams().append("category", this.foodID.toString());
		params = params.append("stock_status", "instock");
		return this.http.get<Shop[]>(`${url}/wp-json/wc/v3/products`, { headers, params });
	}

	getVariations(jwt: string, product: number): Observable<Variation[]> {
		let params = new HttpParams();
		params = params.append("jwt", jwt);
		params = params.append("url", `${url}/wp-json/wc/v3/products/${product}/variations`);
		params = params.append("stock_status", "instock");
		params = params.append("category", "");

		return this.http.get<Variation[]>(`${url}/jwt_validation.php?`, {
			params: params,
		});
	}

	getFood_byId(id: string): Observable<Shop> {
		let params = new HttpParams().append("id", id);
		params = params.append("category", this.foodID.toString());
		params = params.append("stock_status", "instock");
		return this.http.get<Shop>(`${url}/wp-json/wc/v3/products`, { headers, params });
	}
	getBeverage(): Observable<Shop[]> {
		let params = new HttpParams().append("category", this.beverageID.toString());
		params = params.append("stock_status", "instock");
		return this.http.get<Shop[]>(`${url}/wp-json/wc/v3/products`, { headers, params });
	}

	getBeverage_byId(id: string): Observable<Shop> {
		let params = new HttpParams().append("id", id);
		params = params.append("category", this.beverageID.toString());
		params = params.append("stock_status", "instock");
		return this.http.get<Shop>(`${url}/wp-json/wc/v3/products`, { headers, params });
	}
}
